from setuptools import setup

setup(name='gbd_stat',
      version='0.1',
      description='Gaussian distributions',
      packages=['gbd_stat'],
      author = 'Arjun Maini',
      author_email = 'arjunmaini007@gmail.com',
      zip_safe=False)
